stack sizes: reduce stack sizes for modules that use sensor_combined

The sensor_combined topic got reduced from ~780 bytes to 72 bytes.
This commit is contained in:
Beat Küng
2016-07-07 11:35:50 +02:00
committed by Lorenz Meier
parent c5ea4b43be
commit 8e136779ec
6 changed files with 6 additions and 6 deletions
+1 -1
View File
@@ -2478,7 +2478,7 @@ Sensors::start()
_sensors_task = px4_task_spawn_cmd("sensors",
SCHED_DEFAULT,
SCHED_PRIORITY_MAX - 5,
2200,
1500,
(px4_main_t)&Sensors::task_main_trampoline,
nullptr);